import json
import requests
from api_error import api_error
from update_detail import update_detail


class update_check_helper:
    _apiKey = None
    _baseUrl = None

    def __init__(self, api_key, base_url):
        self._apiKey = api_key
        self._baseUrl = base_url + "api/device/update/check"

    def check_update(self, request, callback):
        """

        :type callback: function
        :type request: update_detail_request.update_detail_request
        """
        headers = {'Authorization': self._apiKey, 'Content-Type': 'application/json'}

        check_update_data = {
            'unitId': request.unitId,
            'versionId': request.versionId
        }
        print(self._baseUrl)
        rep = requests.post(self._baseUrl, data=json.dumps(check_update_data), headers=headers, verify=False)
        print("json %s" % rep.json)

        if rep.status_code == 200:
            if rep.json is not None:
                callback(update_detail(rep.json()))
                return rep.json()
            else:
                callback(api_error.ApiError(" > Error: Response 200 without json"), rep.status_code)
                return rep.json()
        else:
            callback(api_error.ApiError("Error", rep.status_code))
            return rep.json()



from package_download_helper import package_download_helper
from update_check_helper import update_check_helper


class barracks_helper:
    _apiKey = None
    _baseUrl = None

    packageDownloadHelper = None
    updateCheckerHelper = None

    def __init__(self, api_key, base_url=None):
        """

        :type base_url: basestring
        :type api_key: basestring
        """
        self.apiKey = api_key
        self._baseUrl = base_url if base_url is not None else "https://app.barracks.io/"

        self.packageDownloadHelper = package_download_helper(api_key)
        self.updateCheckerHelper = update_check_helper(api_key, self._baseUrl)

    def get_api_key(self):
        return self._apiKey



class api_error:

    _message = None
    _error_code = None

    def __init__(self, message, error_code = None):
        self._message = message
        self._error_code = error_code

    def get_message(self):
        return self._message

    def get_error_code(self):
        return self._error_code



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    This module provides the Barracks API implementation
"""

from api_error import api_error
from barracks_helper import barracks_helper
from package_download_helper import package_download_helper
from package_info import package_info
from update_check_helper import update_check_helper
from update_detail import update_detail
from update_detail_request import update_detail_request

__all__ = ["update_detail", "update_detail_request", "package_download_helper", "barracks_helper", "api_error",
           "package_info",
           "update_check_helper"]

__version__ = "0.0.1"



from package_info import package_info


class update_detail:
    _packageInfo = None
    _versionId = None
    _properties = None

    def __init__(self, json=None):
        if json is not None:
            self._versionId = json['versionId']
            self._packageInfo = package_info(json['packageInfo'])
            self._properties = json['properties']

    def get_package_info(self):
        return self._packageInfo



class package_info:
    _url = None
    _md5 = None
    _size = None

    def __init__(self, json=None):
        if json is not None:
            self._url = json['url']
            self._md5 = json['md5']
            self._size = json['size']

    def get_url(self):
        return self._url

    def get_md5(self):
        return self._md5

    def get_size(self):
        return self._size



import hashlib
import os
import sys
import requests
from api_error import api_error


def check_md5(file_path, md5):
    return md5 == hashlib.md5(open(file_path, 'rb').read()).hexdigest()


class package_download_helper:
    _apiKey = None

    def __init__(self, api_key):
        self._apiKey = api_key

    def download_package(self, temporary_path, update_detail, callback):
        """

        :type callback: function
        :type temporary_path: string
        :type update_detail: update_detail.update_detail
        """
        # Download the file
        url = update_detail.get_package_info().get_url()
        f = self.download_file(url, temporary_path)
        full_path = os.path.realpath(f)

        if check_md5(full_path, update_detail.get_package_info().get_md5()):
            print("update url = %s" % update_detail.get_package_info().get_url())
            callback(f)
            return True
        else:
            error = api_error("Md5 does not match")
            callback(error)
            return error

    def download_file(self, url, tmp_path):
        headers = {'Authorization': self._apiKey, 'Content-Type': 'application/json'}
        r = requests.get(url, stream=True, headers=headers, verify=False)
        with open(tmp_path, 'wb') as f:
            print('Start downloading')
            sys.stdout.flush()
            for chunk in r.iter_content(chunk_size=1024):
                if chunk:  # filter out keep-alive new chunks
                    f.write(chunk)
        return tmp_path



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

import barracks_sdk

setup(
    name='barracks_sdk',
    version=barracks_sdk.__version__,
    packages=find_packages(),
    author="Pierre-Olivier Dybman",
    author_email="pod+sdk@barracks.io",
    description="API implementation for Barracks",
    long_description=open('README.md').read(),
    install_requires=open('requirements.txt').read(),
    url='http://barracks.io',
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Topic :: Home Automation",
    ],
    entry_points=None,
    license="ALv2"
)



class update_detail_request:
    versionId = None
    unitId = None
    properties = None

    def __init__(self, versionId, unitId, properties):
        self.versionId = versionId
        self.unitId = unitId
        self.properties = properties
